@@ -8,7 +8,7 @@ from transformers import BertModel, BertTokenizerFast
 from .model import GlobalPointer
 from .utils import rematch
 
-__all__=['load_NNER', 'GlobalPointerNet']
+__all__=['load_NNER']
 
 
 class _CustomDataset4test(Dataset):
@@ -31,9 +31,9 @@ class _CustomDataset4test(Dataset):
 
         return enc_context
 
-class GlobalPointerNet(nn.Module):
+class _GlobalPointerNet(nn.Module):
     def __init__(self, model_name, c_size=9, head_size=64, embedding_size=1024):
-        super(GlobalPointerNet, self).__init__()
+        super(_GlobalPointerNet, self).__init__()
         self.head = GlobalPointer(c_size, head_size, embedding_size)
         self.bert = BertModel.from_pretrained(model_name)
 
@@ -122,17 +122,17 @@ class _NamedEntityRecognizer(object):
 
 _id2c = {0: 'dis', 1: 'sym', 2: 'pro', 3: 'equ', 4: 'dru', 5: 'ite', 6: 'bod', 7: 'dep', 8: 'mic'}
 
-def load_NNER(model_save_path='./checkpoint/68.2796_macbert_large/macbert-large', 
+def load_NNER(model_save_path='./checkpoint/macbert-large_dict.pth', 
                 maxlen=512, c_size=9, id2c=_id2c):
     '''
     Args:
         model_save_path (string, optional): path of pretrained model
-            Default: './checkpoint/macbert-large'
+            Default: './checkpoint/macbert-large_dict.pth'
         maxlen (int, optional): max length of sentence
             Default: 512
-        c_size (int, optional): number of c???
+        c_size (int, optional): number of entity class
             Default: 9
-        id2c (dictionary, optional): mapping between id and c???
+        id2c (dictionary, optional): mapping between id and entity class
             Default: _id2c
     '''
     device = torch.device('cuda') if torch.cuda.is_available() else torch.device('cpu')
@@ -141,20 +141,19 @@ def load_NNER(model_save_path='./checkpoint/68.2796_macbert_large/macbert-large'
     model_name = 'hfl/chinese-macbert-large'
     tokenizer = BertTokenizerFast.from_pretrained(model_name)
     tokenizer.add_special_tokens({'pad_token': '[PAD]'})
+    model_base = _GlobalPointerNet(model_name).to(device)
 
     if not os.path.exists(model_save_path):
         model_dir = os.path.dirname(model_save_path)
         os.makedirs(model_dir)
         # Reference:
         # https://github.com/pytorch/pytorch/blob/b5b62b340891f041b378681577c74922d21700a9/torch/hub.py
-        url = 'https://github.com/cb1cyf/NNER/releases/download/v0.0.1/macbert-large'
-        try:
-            model_base = torch.hub.load_state_dict_from_url(url, model_dir)
-        except:
-            torch.hub.download_url_to_file(url, model_save_path)
-            model_base = torch.load(model_save_path)
-    else:
-        model_base = torch.load(model_save_path)
+        url = 'https://github.com/cb1cyf/NNER/releases/download/v0.0.1/macbert-large_dict.pth'
+        #model_base = torch.hub.load_state_dict_from_url(url, model_dir)
+        torch.hub.download_url_to_file(url, model_save_path)
+    state_dict = torch.load(model_save_path, map_location=device)
+    # multi-gpu -> 1 gpu
+    model_base.load_state_dict({k.replace('module.', ''): v for k, v in state_dict.items()})
     NER = _NamedEntityRecognizer(maxlen, c_size, id2c, device, tokenizer, model_base)
     return NER
 
@@ -212,8 +211,6 @@ def infer(in_file, out_file='./CMeEE_test_answer.json',
 
 
 if __name__ == '__main__':
-    model = GlobalPointerNet('hfl/chinese-macbert-large')
-
     in_file = '../CMeEE_test.json'
     #infer(in_file)
 
